(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     18205,        460]
NotebookOptionsPosition[     18424,        444]
NotebookOutlinePosition[     18879,        464]
CellTagsIndexPosition[     18836,        461]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Force Vector Projection",
 FontSize->36]], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "2dc5de90-70a1-490f-ac26-014615c3b4ab"],

Cell["\<\
Based on the problem 2-137 of R. C. Hibbeler\[CloseCurlyQuote]s Statics, 13th \
edition\
\>", "Text",
 TextAlignment->Center],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Allen Lang, Baoxing Xu\nUniversity of Virginia, \
2018-10-11",
 FontSize->18,
 FontColor->GrayLevel[0]]], "Chapter",
 TextAlignment->Center,
 ExpressionUUID -> "e1c4552d-fab2-4d4d-ae20-af47234c711e"],

Cell[TextData[{
 "The following module expands upon basics in vector representation, position \
vectors, and vector projection. \nAs review, projections of a force onto any \
certain line can be easily found once a force is already represented as a \
vector. In problem 137, the components of ",
 StyleBox["F ",
  FontWeight->"Bold"],
 "that act along rod AC and perpendicular to it must be found. The Force \
vector can be found using the given magnitude and given information that the \
force acts in the same direction as a vector from B to D. For the projection \
of the Force vector onto the rod AC, the component can be found using the \n\
dot product between the force vector and the unit vector along the desired \
projection direction. Alternatively, cosine may be used if the angle between \
BD and AC is known."
}], "Text",
 ExpressionUUID -> "8dcf9656-aa73-4006-8c8e-b6b2a971f525"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["F", "||"], " ", "=", " ", 
   RowBox[{
    StyleBox[
     RowBox[{"F", " ", "\[Bullet]", " ", 
      SubscriptBox["u", "AC"]}],
     FontWeight->"Bold"], 
    StyleBox["=",
     FontWeight->"Plain"], 
    RowBox[{
     StyleBox["|",
      FontWeight->"Plain"], 
     StyleBox["F",
      FontWeight->"Bold"], 
     StyleBox["|",
      FontWeight->"Plain"], 
     StyleBox["cos\[Theta]",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Bold"]}]}]}], TraditionalForm]],
 ExpressionUUID -> "3b013abd-3d56-4c8c-b68c-ed1bda6b0ab5"]], "Text",
 TextAlignment->Center,
 ExpressionUUID -> "b764abfe-2c7f-4e2d-a8f6-fc0cdfc99afd"],

Cell["\<\
The component of the perpendicular force may be found using the following \
relation\
\>", "Text"],

Cell[TextData[Cell[BoxData[
 RowBox[{
  StyleBox["F",
   FontSlant->"Italic"], 
  StyleBox["=",
   FontSlant->"Italic"], 
  RowBox[{
   SubscriptBox[
    SubsuperscriptBox[
     RowBox[{
      StyleBox["F",
       FontSlant->"Italic"], " "}], "\[UpTee]", "2"], 
    FormBox[" ",
     TraditionalForm]], "+", 
   SubsuperscriptBox[
    RowBox[{
     StyleBox["F",
      FontSlant->"Italic"], " "}], "||", "2"]}]}]],
 TextAlignment->Center,
 ExpressionUUID -> "ef20cef3-f0b6-40a0-af86-2376604c723a"]], "Text",
 TextAlignment->Center,
 ExpressionUUID -> "b764abfe-2c7f-4e2d-a8f6-fc0cdfc99afd"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dist$$ = 3, $CellContext`magForce$$ = 
    600, $CellContext`opa1$$ = 0, $CellContext`xC$$ = -1, $CellContext`xD$$ = 
    2, $CellContext`yC$$ = 5, $CellContext`yD$$ = 5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`dist$$], 3, 
       Style[$CellContext`R, Italic]}, 0, 
      Dynamic[
       Sqrt[4^2 + $CellContext`xC$$^2 + $CellContext`yC$$^2]]}, {{
       Hold[$CellContext`xC$$], -1, 
       Style[
        Subscript[$CellContext`x, C], Italic]}, -6, 6}, {{
       Hold[$CellContext`yC$$], 5, 
       Style[
        Subscript[$CellContext`y, C], Italic]}, -6, 6}, {{
       Hold[$CellContext`xD$$], 2, 
       Style[
        Subscript[$CellContext`x, D], Italic]}, -6, 6}, {{
       Hold[$CellContext`yD$$], 5, 
       Style[
        Subscript[$CellContext`y, D], Italic]}, -6, 6}, {{
       Hold[$CellContext`magForce$$], 600, 
       Style["| F |", Bold]}, -1000, 1000}, {{
       Hold[$CellContext`opa1$$], 0, 
       Text[
        Style[
         Row[{
           Column[{"Projection of", "force on line"}, Spacings -> 0.5], 
           Spacer[33]}], 12]]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Row[{
            Text[
             Style["Distance from C along Rod", 12, Bold]]}, Alignment -> 
           Left]}, {
          Manipulate`Place[1]}, {
          Row[{
            Text[
             Style["Point C coordinate", 12, Bold]]}, Alignment -> Left]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Row[{
            Text[
             Style["Point D coordinate", 12, Bold]]}, Alignment -> Left]}, {
          Manipulate`Place[4]}, {
          Manipulate`Place[5]}, {
          Row[{
            Text[
             Style["Magnitude of Force", 12, Bold]]}, Alignment -> Left]}, {
          Manipulate`Place[6]}, {
          Manipulate`Place[7]}, {
          Column[{
            Row[{
              Dynamic[
               If[$CellContext`opa1$$ == 1, $CellContext`temp1 = Row[{
                   Text[
                    Style[
                    Subscript["F", "\[DoubleVerticalBar]"], Italic]], 
                   Spacer[4], "=", 
                   Spacer[5], 
                   Dynamic[
                    NumberForm[$CellContext`fPara]]}], 
                Invisible[$CellContext`temp1]]]}, Alignment -> Left], 
            Row[{
              Dynamic[
               If[$CellContext`opa1$$ == 1, $CellContext`temp1 = Row[{
                   Text[
                    Style[
                    Subscript["F", "\[UpTee]"], Italic]], 
                   Spacer[6], "=", 
                   Spacer[10], 
                   Dynamic[
                    NumberForm[$CellContext`fPerp]]}], 
                Invisible[$CellContext`temp1]]]}, Alignment -> Left]}, Null, 
           Spacings -> 0.5]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {540., {295., 304.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`dist$75433$$ = 0, $CellContext`xC$75434$$ = 
    0, $CellContext`yC$75435$$ = 0, $CellContext`xD$75436$$ = 
    0, $CellContext`yD$75437$$ = 0, $CellContext`magForce$75438$$ = 
    0, $CellContext`opa1$75439$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`dist$$ = 3, $CellContext`magForce$$ = 
        600, $CellContext`opa1$$ = 
        0, $CellContext`xC$$ = -1, $CellContext`xD$$ = 2, $CellContext`yC$$ = 
        5, $CellContext`yD$$ = 5}, "ControllerVariables" :> {
        Hold[$CellContext`dist$$, $CellContext`dist$75433$$, 0], 
        Hold[$CellContext`xC$$, $CellContext`xC$75434$$, 0], 
        Hold[$CellContext`yC$$, $CellContext`yC$75435$$, 0], 
        Hold[$CellContext`xD$$, $CellContext`xD$75436$$, 0], 
        Hold[$CellContext`yD$$, $CellContext`yD$75437$$, 0], 
        Hold[$CellContext`magForce$$, $CellContext`magForce$75438$$, 0], 
        Hold[$CellContext`opa1$$, $CellContext`opa1$75439$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`dwf0$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dw1$, $CellContext`dw2$, $CellContext`dw3$}, \
$CellContext`size = 8; $CellContext`coef = 
         200; $CellContext`alongB = $CellContext`dist$$; $CellContext`pointA = \
{0, 0, 4}; $CellContext`pointC = {$CellContext`xC$$, $CellContext`yC$$, 
           0}; $CellContext`pointD = {$CellContext`xD$$, $CellContext`yD$$, 
           0}; $CellContext`magF = $CellContext`magForce$$; $CellContext`rCA = \
$CellContext`pointA - $CellContext`pointC; $CellContext`magCA = N[
           
           Norm[$CellContext`rCA]]; $CellContext`rCB = \
($CellContext`alongB/$CellContext`magCA) $CellContext`rCA; \
$CellContext`pointB = $CellContext`pointC + $CellContext`rCB; \
$CellContext`rBD = $CellContext`pointD - $CellContext`pointB; $CellContext`F = \
$CellContext`magF 
          Normalize[$CellContext`rBD]; $CellContext`rAC = $CellContext`pointC - \
$CellContext`pointA; $CellContext`uAC = N[
           Normalize[$CellContext`rAC]]; $CellContext`fPara = 
         Dot[$CellContext`F, $CellContext`uAC]; $CellContext`fPerp = 
         Sqrt[$CellContext`magF^2 - $CellContext`fPara^2]; \
$CellContext`ProjPerp = 
         Projection[$CellContext`F/$CellContext`coef, $CellContext`uAC]; \
$CellContext`dwf0$ = {
           Opacity[1], 
           Dashing[{}], 
           Thickness[0.005], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size, 0, 0}, {$CellContext`size, 0, 0}}], 
           Arrow[{{0, -$CellContext`size, 0}, {0, $CellContext`size, 0}}], 
           Arrow[{{0, 0, -$CellContext`size}, {0, 0, $CellContext`size}}], 
           Text[
           "\!\(\*StyleBox[\"x\",FontWeight->\"Bold\",FontSlant->\"Italic\"]\)\
", {1.1 $CellContext`size, (-0.05) $CellContext`size, (-0.05) \
$CellContext`size}], 
           Text[
           "y", {(-0.05) $CellContext`size, 1.1 $CellContext`size, 
             0.05 $CellContext`size}], 
           Text[
           "\!\(\*StyleBox[\"z\",FontWeight->\"Bold\",FontSlant->\"Italic\"]\)\
", {(-0.05) $CellContext`size, (-0.05) $CellContext`size, 
             1.1 $CellContext`size}]}; $CellContext`dwf1$ = {
           Opacity[1], Brown, 
           Thickness[0.005], 
           
           Line[{$CellContext`pointA, $CellContext`pointC}]}; \
$CellContext`dwf2$ = {
           Opacity[1], Black, 
           PointSize[0.015], 
           Point[$CellContext`pointA], 
           Text[
            Style["A", 12, Bold], $CellContext`pointA + {-1, 0, 0}], 
           Point[$CellContext`pointC], 
           Text[
            Style["C", 12, Bold], $CellContext`pointC + {-1, 0, 0}], 
           Point[$CellContext`pointD], 
           Text[
            Style[
            "D", 12, Bold], $CellContext`pointD + {1, 0, 
             0}]}; $CellContext`dwf3$ = {
           Opacity[1], Black, 
           PointSize[0.015], 
           Point[$CellContext`pointB], 
           Text[
            Style[
            "B", 12, Bold], $CellContext`pointB + {0, 0, 
             1}]}; $CellContext`dwf4$ = {
           Opacity[1], Red, 
           Thickness[0.007], 
           Arrowheads[0.03], 
           
           Arrow[{$CellContext`pointB, $CellContext`pointB + \
$CellContext`F/$CellContext`coef}]}; $CellContext`dwf5$ = {
           Opacity[1], Black, Dashed, 
           
           Line[{$CellContext`pointB, $CellContext`pointD}]}; \
$CellContext`dwf6$ = {
           Opacity[1], Black, Dashed, 
           Line[{{$CellContext`xC$$, 0, 0}, $CellContext`pointC}], 
           Line[{{0, $CellContext`yC$$, 0}, $CellContext`pointC}], 
           Line[{{$CellContext`xD$$, 0, 0}, $CellContext`pointD}], 
           
           Line[{{0, $CellContext`yD$$, 
              0}, $CellContext`pointD}]}; $CellContext`dwf7$ = {
           Opacity[$CellContext`opa1$$], Blue, 
           Thickness[0.005], 
           Arrowheads[0.03], 
           
           Arrow[{$CellContext`pointB, $CellContext`pointB + \
$CellContext`ProjPerp}], 
           
           Arrow[{$CellContext`pointB, $CellContext`pointB + \
($CellContext`F/$CellContext`coef - $CellContext`ProjPerp)}]}; \
$CellContext`dwf8$ = {
           Opacity[$CellContext`opa1$$ 0.5], Cyan, 
           
           Triangle[{$CellContext`pointB, $CellContext`pointB + \
$CellContext`F/$CellContext`coef, $CellContext`pointB + \
$CellContext`ProjPerp}]}; $CellContext`dwf9$ = {
           Opacity[$CellContext`opa1$$ 0.5], Cyan, 
           
           Triangle[{$CellContext`pointB, $CellContext`pointB + \
$CellContext`F/$CellContext`coef, $CellContext`pointB + \
$CellContext`F/$CellContext`coef - $CellContext`ProjPerp}]}; \
$CellContext`dw1$ = 
         Graphics3D[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$}, PlotRange -> 
           1.05 $CellContext`size, Boxed -> False, 
           ViewPoint -> {
            0.5 $CellContext`size, 0.5 $CellContext`size, 
             0.5 $CellContext`size}]; $CellContext`dw2$ = Graphics3D[{
            Opacity[0.1], Gray, 
            
            Polygon[{{$CellContext`size, $CellContext`size, 
               0}, {$CellContext`size, -$CellContext`size, 
               0}, {-$CellContext`size, -$CellContext`size, 
               0}, {-$CellContext`size, $CellContext`size, 
               0}}]}]; $CellContext`dw3$ = Graphics3D[{
            EdgeForm[], $CellContext`dwf8$, $CellContext`dwf9$}]; 
        Show[$CellContext`dw1$, $CellContext`dw2$, $CellContext`dw3$]], 
      "Specifications" :> {{{$CellContext`dist$$, 3, 
          Style[$CellContext`R, Italic]}, 0, 
         Dynamic[
          Sqrt[4^2 + $CellContext`xC$$^2 + $CellContext`yC$$^2]], ImageSize -> 
         Tiny, Appearance -> "Labeled", ControlPlacement -> 
         1}, {{$CellContext`xC$$, -1, 
          Style[
           Subscript[$CellContext`x, C], Italic]}, -6, 6, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         2}, {{$CellContext`yC$$, 5, 
          Style[
           Subscript[$CellContext`y, C], Italic]}, -6, 6, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         3}, {{$CellContext`xD$$, 2, 
          Style[
           Subscript[$CellContext`x, D], Italic]}, -6, 6, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         4}, {{$CellContext`yD$$, 5, 
          Style[
           Subscript[$CellContext`y, D], Italic]}, -6, 6, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         5}, {{$CellContext`magForce$$, 600, 
          Style["| F |", Bold]}, -1000, 1000, ImageSize -> Tiny, Appearance -> 
         "Labeled", ControlPlacement -> 6}, {{$CellContext`opa1$$, 0, 
          Text[
           Style[
            Row[{
              Column[{"Projection of", "force on line"}, Spacings -> 0.5], 
              Spacer[33]}], 12]]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 7}, 
        Grid[{{
           Row[{
             Text[
              Style["Distance from C along Rod", 12, Bold]]}, Alignment -> 
            Left]}, {
           Manipulate`Place[1]}, {
           Row[{
             Text[
              Style["Point C coordinate", 12, Bold]]}, Alignment -> Left]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Row[{
             Text[
              Style["Point D coordinate", 12, Bold]]}, Alignment -> Left]}, {
           Manipulate`Place[4]}, {
           Manipulate`Place[5]}, {
           Row[{
             Text[
              Style["Magnitude of Force", 12, Bold]]}, Alignment -> Left]}, {
           Manipulate`Place[6]}, {
           Manipulate`Place[7]}, {
           Column[{
             Row[{
               Dynamic[
                If[$CellContext`opa1$$ == 1, $CellContext`temp1 = Row[{
                    Text[
                    Style[
                    Subscript["F", "\[DoubleVerticalBar]"], Italic]], 
                    Spacer[4], "=", 
                    Spacer[5], 
                    Dynamic[
                    NumberForm[$CellContext`fPara]]}], 
                 Invisible[$CellContext`temp1]]]}, Alignment -> Left], 
             Row[{
               Dynamic[
                If[$CellContext`opa1$$ == 1, $CellContext`temp1 = Row[{
                    Text[
                    Style[
                    Subscript["F", "\[UpTee]"], Italic]], 
                    Spacer[6], "=", 
                    Spacer[10], 
                    Dynamic[
                    NumberForm[$CellContext`fPerp]]}], 
                 Invisible[$CellContext`temp1]]]}, Alignment -> Left]}, Null, 
            Spacings -> 0.5]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{891., {340., 349.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "109a7780-439a-40ef-b680-b646df7ce133"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification->1.5,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 158, 3, 134, "Title"],
Cell[1647, 40, 135, 4, 45, "Text"],
Cell[CellGroupData[{
Cell[1807, 48, 223, 5, 119, "Chapter"],
Cell[2033, 55, 893, 15, 159, "Text"],
Cell[2929, 72, 703, 24, 48, "Text"],
Cell[3635, 98, 108, 3, 45, "Text"],
Cell[3746, 103, 590, 21, 50, "Text"],
Cell[4339, 126, 14057, 314, 713, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Kv0TuImxW8ZqKDKugOSMm2Rd *)
